package cn.iocoder.yudao.module.inspection.service;

import java.util.List;

import cn.iocoder.yudao.module.inspection.entity.NweUsers;
import cn.iocoder.yudao.module.inspection.entity.SiteInfo;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

/**
 * inspectionService接口
 *
 * @author zcy
 * @date 2023-09-01
 */
public interface ISiteInfoService
{
    /**
     * 查询inspection
     *
     * @param id inspection主键
     * @return inspection
     */
    public SiteInfo selectSiteInfoById(Long id);

    /**
     * 查询inspection列表
     *
     * @param siteInfo inspection
     * @return inspection集合
     */
    public IPage<SiteInfo> selectSiteInfoList(Page<SiteInfo> page, SiteInfo siteInfo);

    /**
     * 新增inspection
     *
     * @param siteInfo inspection
     * @return 结果
     */
    public int insertSiteInfo(SiteInfo siteInfo);

    /**
     * 修改inspection
     *
     * @param siteInfo inspection
     * @return 结果
     */
    public int updateSiteInfo(SiteInfo siteInfo);

    /**
     * 批量删除inspection
     *
     * @param ids 需要删除的inspection主键集合
     * @return 结果
     */
    public int deleteSiteInfoByIds(Long[] ids);

    /**
     * 删除inspection信息
     *
     * @param id inspection主键
     * @return 结果
     */
    public int deleteSiteInfoById(Long id);

    /**
     * 迁移数据表：查询老表数据
     *
     * @return JSONObject对象集合
     */
    public List<JSONObject> transferDB();

    /**
     * 迁移数据表：向新表中插入数据
     *
     * @return 影响行数
     */
    public int addNewDB(NweUsers user);


    /**
     * 修改user_id
     */
    public int updateUserId1(int newUserId,int oldUserId);
    public int updateUserId2(int newUserId,int oldUserId);
    public int updateUserId3(int newUserId,int oldUserId);
    public int updateUserId4(int newUserId,int oldUserId);
    public int updateUserId5(int newUserId,int oldUserId);



}
